PagesAndDialogAccesss class

Constructors

PagesAndDialogAccesss(Map<String, bool> pagesAccess, Map<String, bool> dialogsAccess, Map<String, bool> packageConditionsAccess, PrivilegeLevel? privilegeLevel, bool? blocked)

Properties

blocked → bool?
final
dialogsAccess → Map<String, bool>
final
hashCode → int
The hash code for this object.
no setter
packageConditionsAccess → Map<String, bool>
final
pagesAccess → Map<String, bool>
final
privilegeLevel → PrivilegeLevel?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({Map<String, bool>? pagesAccess, Map<String, bool>? dialogsAccess, Map<String, bool>? packageConditionsAccess, PrivilegeLevel? privilegeLevel, bool? blocked}) → PagesAndDialogAccesss
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.