AccessDetermined class abstract

Inheritance
Implementers

Constructors

AccessDetermined(List<DeterminedApp> apps, Map<String, PagesAndDialogAccesss> accesses, {AppModel? playstoreApp, bool? isProcessing, String? tempMessage, int? newForceRefresh})

Properties

accesses → Map<String, PagesAndDialogAccesss>
final
apps → List<DeterminedApp>
final
forceRefresh → int
final
hashCode → int
The hash code for this object.
no setterinherited
isProcessing → bool?
final
playstoreApp → AppModel?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tempMessage → String?
final

Methods

actionHasAccess(ActionModel action) → Future<bool>
addApp(AccessBloc accessBloc, AppModel newCurrentApp) → Future<AccessDetermined>
addApp2(AccessBloc accessBloc, Map<String, PagesAndDialogAccesss> accesses, List<DeterminedApp> apps, AppModel newCurrentApp) → Future<AccessDetermined>
asNotProcessing() → AccessDetermined
asProcessing() → AccessDetermined
clearTempMessage() → AccessDetermined
forceAcceptMembership(String appId) → bool
inherited
getApp(String appId) → AppModel?
getMember() → MemberModel?
override
getMemberCollectionInfo() → List<MemberCollectionInfo>?
inherited
getPrivilegeLevel(String appId) → PrivilegeLevel
getPrivilegeLevelCurrentApp(String currentAppId) → PrivilegeLevel
hasAccessToOtherApps() → bool
inherited
hasNAccess(List<MenuItemModel> items) → Future<List<bool>>
homePageForAppId(String appId) → PageModel?
isBlocked(String appId) → bool
isCurrentAppBlocked(String currentAppId) → bool
isLoggedIn() → bool
inherited
isProcessingStatus() → bool
memberIsOwner(String appId) → bool
inherited
newVersion() → AccessDetermined
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reterminedHomePageForAppId(AppModel app) → Future<PageModel?>
toString() → String
A string representation of this object.
inherited
updateApp2(AccessBloc accessBloc, AppModel newCurrentApp) → Future<AccessDetermined>
updateApps(AppModel newCurrentApp, List<DeterminedApp> newApps) → Future<AccessDetermined>
updateMember(MemberModel member) → AccessDetermined
withDifferentPackageCondition(String appId, Package package, String packageCondition, bool value) → AccessDetermined
withNewAccess(AccessBloc accessBloc, AccessModel access) → Future<AccessDetermined>
withNewAccesses(Map<String, PagesAndDialogAccesss> newAccesses) → AccessDetermined
withOtherPrivilege(AccessBloc accessBloc, AppModel app, PrivilegeLevel privilege, bool blocked) → Future<AccessDetermined>
withTempMessage(String message) → AccessDetermined

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getPage(String appId, String? pageId, {String? alternativePageId}) → Future<PageModel?>