Registry class

Properties

componentDropDownSupporters ↔ Map<String, ComponentDropDown>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rootScaffoldMessengerKey → GlobalKey<ScaffoldMessengerState>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addComponentSpec(String pluginName, String pluginFriendlyName, List<ComponentSpec> specs) → void
addDropDownSupporter(String componentId, ComponentDropDown support) → void
addInternalComponents(String pluginName, List<String> list) → void
allInternalComponents(String pluginName) → List<String>?
application({required AppModel app, required bool asPlaystore}) → Widget
component(BuildContext context, AppModel app, String componentName, String id, {Map<String, dynamic>? parameters, Key? key}) → Widget
componentAccessValidation(BuildContext context, AccessDetermined accessDetermined, AppModel currentApp, String component, String id, dynamic model) → bool
componentSpecMap() → Map<String, List<ComponentSpec>>
error({required String appId, required String error}) → Widget
getApp(String appId) → Future<AppModel?>
getComponentSpecs(String name) → ComponentSpec?
getExtensions() → List<String>
getRetrieveRepository(String pluginName, String componentId) → RetrieveRepository?
getSupportingDropDown(String componentId) → ComponentDropDown?
internalComponents() → Map<String, List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDialog(BuildContext context, {required AppModel app, required String id, Map<String, dynamic>? parameters}) → Future<void>
openSelectActionWidget({required AppModel app, required ActionModel? action, required ActionSelected actionSelected, required int containerPrivilege, required String label}) → Widget
packageFriendlyNames() → Map<String, String>
page({required String appId, required String pageId, Map<String, dynamic>? parameters}) → Widget
register({String? componentName, ComponentConstructor? componentConstructor}) → void
registerOpenSelectActionWidgetFnct(OpenSelectActionWidgetFnct openSelectActionWidgetFnct) → void
registerRetrieveRepository(String pluginName, String componentId, RetrieveRepository repository) → void
registryMap() → Map<String?, ComponentConstructor?>
snackbar(String text, {String? snackbarActionLabel, dynamic action()?}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

getter/setter pair

Static Methods

registry() → Registry?