ComponentInfo class

Constructors

ComponentInfo(List<BodyComponentModel>? componentModels, Map<String, dynamic>? parameters, List<Widget> widgets, HasFab? hasFab, Layout layout, BackgroundModel? backgroundOverride, GridViewModel? gridView)

Properties

backgroundOverride → BackgroundModel?
final
componentModels → List<BodyComponentModel>?
final
gridView → GridViewModel?
final
hasFab → HasFab?
final
hashCode → int
The hash code for this object.
no setterinherited
layout → Layout
final
parameters → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widgets → List<Widget>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getComponentInfo(BuildContext context, AppModel app, List<BodyComponentModel>? componentModels, Map<String, dynamic>? parameters, Layout layout, BackgroundModel? background, GridViewModel? gridView) → ComponentInfo