Param class abstract

Implementers

Constructors

Param(int position, String original)

Properties

hashCode → int
The hash code for this object.
no setterinherited
original → String
final
position → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceParamInStringWithDouble(String toReplace, double value) → String
replaceParamInStringWithString(String toReplace, String value) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited