SingleValue class

Inheritance

Constructors

SingleValue(int position, String original)

Properties

hashCode → int
The hash code for this object.
no setterinherited
original → String
finalinherited
position → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceParamInStringWithDouble(String toReplace, double value) → String
inherited
replaceParamInStringWithString(String toReplace, String value) → String
inherited
toString() → String
A string representation of this object.
override
value() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited