SelectWidget<T> class

Inheritance

Constructors

SelectWidget({Key? key, required AppModel app, required T? currentlySelected, required void selectedCallback(dynamic selected), required String title, required String selectTitle, required Widget displayItemFunction(dynamic item), required Widget blocBuilder(ListContentProvider contentsLoaded, NoContentProvider contentsNotLoaded), required BlocProvider<StateStreamableSource<Object?>> blocProviderProvider(), ChangePrivilegeEventCallback? changePrivilegeEventCallback, int? containerPrivilege, void updateCallback(dynamic selected)?, void deleteCallback(dynamic selected)?, VoidCallback? addCallback})
const

Properties

addCallback → VoidCallback?
final
app → AppModel
final
blocBuilder → Widget Function(ListContentProvider contentsLoaded, NoContentProvider contentsNotLoaded)
final
blocProviderProvider → BlocProvider<StateStreamableSource<Object?>> Function()
final
changePrivilegeEventCallback → ChangePrivilegeEventCallback?
final
containerPrivilege → int?
final
currentlySelected → T?
final
deleteCallback → void Function(dynamic selected)?
final
displayItemFunction → Widget Function(dynamic item)
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedCallback → void Function(dynamic selected)
final
selectTitle → String
final
title → String
final
updateCallback → void Function(dynamic selected)?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited