JoinActionSpecifications class

Inheritance
  • Object
  • ActionSpecification
  • JoinActionSpecifications

Constructors

JoinActionSpecifications({required JoinPaymentType paymentType, required bool requiresAccessToLocalFileSystem, required bool availableInLeftDrawer, required bool availableInRightDrawer, required bool availableInAppBar, required bool availableInHomeMenu, required bool available})

Properties

available ↔ bool
getter/setter pairinherited
availableInAppBar ↔ bool
getter/setter pairinherited
availableInHomeMenu ↔ bool
getter/setter pairinherited
availableInLeftDrawer ↔ bool
getter/setter pairinherited
availableInRightDrawer ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
paymentType → JoinPaymentType
final
requiresAccessToLocalFileSystem ↔ bool
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
should(MenuType type) → bool
inherited
shouldCreatePageDialogOrWorkflow() → bool
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited